@@ -1,3 +1,5 @@
+from os import path as osp
+
 # legacy imports, future imports should use the full import path
 from blazeutils.datastructures import DumbObject, OrderedProperties, OrderedDict, \
     HtmlAttributeHolder
@@ -17,4 +19,5 @@ from blazeutils.strings import StringIndenter, simplify_string, case_cw2us, \
     case_mc2us, case_us2cw, case_us2mc, randchars, \
     randhash, randnumerics, reindent, simplify_string
 
-VERSION = '0.3.10'
+cdir = osp.abspath(osp.dirname(__file__))
+VERSION = open(osp.join(cdir, 'version.txt')).read().strip()
